/**
  *  \file mailtemplate.cpp
  *  \brief Parsing of Mail Address Specifications
  *  \author Stefan Reuther
  */

#include "net/mailtemplate.h"
#include "encoding.h"
#include "enumerator.h"
#include "net/url.h"

namespace {
    struct MailParams : public KVEnumerator {
        std::string m_Body, m_Subject;

        void handleItem(std::string key, std::string, std::string value);
    };
}

void
MailParams::handleItem(std::string key, std::string, std::string value)
{
    if (key == "body") {
        m_Body = value;
    } else if (key == "subject") {
        m_Subject = value;
    }
}

MailTemplate::MailTemplate()
{ }

MailTemplate::~MailTemplate()
{ }

bool
MailTemplate::parse(std::string text)
{
    std::string::size_type n;
    if (text.size() > 7 && text.compare(0, 7, "mailto:", 7) == 0) {
        /* mailto url */
        text.erase(0, 7);
    } else if ((n = text.find_first_of(":/\\@")) != text.npos && text[n] == '@') {
        /* normal mail address */
    } else {
        /* not a mail address */
        return false;
    }

    MailParams pa;
    Url::trimParameters(text, pa);
    m_Body    = pa.m_Body;
    m_Subject = pa.m_Subject;
    m_Address = text;
    return true;
}

std::string
MailTemplate::toString() const
{
    std::string result = "mailto:" + m_Address;
    char delim = '?';
    if (m_Subject.size()) {
        result += delim;
        result += "subject=";
        result += encodeUrl(m_Subject);
        delim = '&';
    }
    if (m_Body.size()) {
        result += delim;
        result += "body=";
        result += encodeUrl(m_Body);
        delim = '&';
    }
    return result;
}
