/**
  *  \file selection.h
  *  \brief Selection class declaration
  *  \author Stefan Reuther
  */
#ifndef SELECTION_H_INCLUDED
#define SELECTION_H_INCLUDED

#include <string>

class Game;
class Race;
class Action;

/** Selection. Stores the user's currently selected Game, Race and
    Action, and provides an interface to expanding command and URL
    strings in that context. */
class Selection {
 public:
    Selection();

    ~Selection();

    void selectGame(Game* g);

    void selectRace(Race* r);

    void selectAction(Action* a);

    void recheckGame();

    Game* getSelectedGame()
        { return m_Game; }

    Race* getSelectedRace()
        { return m_Race; }

    Action* getSelectedAction()
        { return m_Action; }

    std::string expandString(std::string input);

 private:

    Game* m_Game;

    Race* m_Race;

    Action* m_Action;
};

#endif
