/**
  *  \file util.h
  */
#ifndef UTIL_H_INCLUDED
#define UTIL_H_INCLUDED

#include <string>

/** Delete all objects from a container-of-pointers. Strictly
    speaking, just delete'ing the elements is undefined behaviour, we
    have to set the elements to zero. */
template<class Container>
void
safeClear(Container& c)
{
    for (typename Container::iterator i = c.begin(); i != c.end(); ++i) {
        delete *i;
        *i = 0;
    }
}

/** Safe append to sequence-of-pointers. <tt>safeAppend(c, new Ele())</tt>
    is identical to <tt>c.push_back(new Ele())</tt> but avoids
    the memory leak if push_back throws. */
template<class Container, class Ele>
void
safeAppend(Container& c, Ele* p)
{
    try {
        c.push_back(p);
    }
    catch (...) {
        delete p;
        throw;
    }
}

std::string strTrim(std::string s);
std::string strLTrim(std::string s);
std::string strRTrim(std::string s);

std::string itoa(int i);
bool        atoi(std::string s, int& i);

std::string strLower(std::string s);

std::string eatWord(std::string& s);

int strCaseCmp(std::string a, std::string b);
std::string getParameter(std::string line, std::string parameter);

void fail(std::string what);

bool stringToIntFromList(std::string text, const char*const* table, int& result);

template<typename T>
bool
stringToEnum(std::string text, const char*const* table, T& e)
{
    int result;
    if (stringToIntFromList(text, table, result)) {
        e = static_cast<T>(result);
        return true;
    } else {
        return false;
    }
}

extern const char* const bool_table[];

#endif
